Overview
========

The ``ftw.dashboard.portlets.recentlymodified`` implements a
recentlyModified Portlet, which shows the last changes from a defined section.


Compatibility
=============

Plone 4.1
---------

.. image:: https://jenkins.4teamwork.ch/job/ftw.dashboard.portlets.recentlymodified-master-test-plone-4.1.x.cfg/badge/icon
   :target: https://jenkins.4teamwork.ch/job/ftw.dashboard.portlets.recentlymodified-master-test-plone-4.1.x.cfg


Plone 4.2
---------

.. image:: https://jenkins.4teamwork.ch/job/ftw.dashboard.portlets.recentlymodified-master-test-plone-4.2.x.cfg/badge/icon
   :target: https://jenkins.4teamwork.ch/job/ftw.dashboard.portlets.recentlymodified-master-test-plone-4.2.x.cfg


Plone 4.3
---------

.. image:: https://jenkins.4teamwork.ch/job/ftw.dashboard.portlets.recentlymodified-master-test-plone-4.3.x.cfg/badge/icon
   :target: https://jenkins.4teamwork.ch/job/ftw.dashboard.portlets.recentlymodified-master-test-plone-4.3.x.cfg


Install
=======

- Add ``ftw.dashboard.portlets.recentlymodified`` to your buildout configuration

::

    [instance]
    eggs =
        ftw.dashboard.portlets.recentlymodified

- Run buildout

- Install ``ftw.dashboard.portlets.recentlymodified`` in portal_setup


Links
=====

- Github: https://github.com/4teamwork/ftw.dashboard.portlets.recentlymodified
- Issues: https://github.com/4teamwork/ftw.dashboard.portlets.recentlymodified/issues
- Pypi: http://pypi.python.org/pypi/ftw.dashboard.portlets.recentlymodified
- Continuous integration: https://jenkins.4teamwork.ch/search?q=ftw.dashboard.portlets.recentlymodified


Maintainer
==========

This package is copyright by `4teamwork <http://www.4teamwork.ch/>`_.

``ftw.dashboard.portlets.recentlymodified`` is licensed under GNU General Public License, version 2.
